@@ -14,6 +14,7 @@ import tempfile
 from unittest import mock as mock
 
 from SoftLayer.CLI import exceptions
+from SoftLayer.fixtures import SoftLayer_Product_Order
 from SoftLayer import SoftLayerError
 from SoftLayer import testing
 
@@ -691,19 +692,19 @@ class ServerCLITests(testing.TestCase):
                                            'getResourceRecords')
         getResourceRecords.return_value = []
         createAargs = ({
-            'type': 'a',
-            'host': 'hardware-test1',
-            'domainId': 12345,  # from SoftLayer_Account::getDomains
-            'data': '172.16.1.100',
-            'ttl': 7200
-        },)
+                           'type': 'a',
+                           'host': 'hardware-test1',
+                           'domainId': 12345,  # from SoftLayer_Account::getDomains
+                           'data': '172.16.1.100',
+                           'ttl': 7200
+                       },)
         createPTRargs = ({
-            'type': 'ptr',
-            'host': '100',
-            'domainId': 123456,
-            'data': 'hardware-test1.test.sftlyr.ws',
-            'ttl': 7200
-        },)
+                             'type': 'ptr',
+                             'host': '100',
+                             'domainId': 123456,
+                             'data': 'hardware-test1.test.sftlyr.ws',
+                             'ttl': 7200
+                         },)
 
         result = self.run_command(['hw', 'dns-sync', '1000'])
 
@@ -746,12 +747,12 @@ class ServerCLITests(testing.TestCase):
             }
         }
         createV6args = ({
-            'type': 'aaaa',
-            'host': 'hardware-test1',
-            'domainId': 12345,  # from SoftLayer_Account::getDomains
-            'data': '2607:f0d0:1b01:0023:0000:0000:0000:0004',
-            'ttl': 7200
-        },)
+                            'type': 'aaaa',
+                            'host': 'hardware-test1',
+                            'domainId': 12345,  # from SoftLayer_Account::getDomains
+                            'data': '2607:f0d0:1b01:0023:0000:0000:0000:0004',
+                            'ttl': 7200
+                        },)
         server.return_value = test_server
         result = self.run_command(['hw', 'dns-sync', '--aaaa-record', '1000'])
         self.assert_no_fail(result)
@@ -936,9 +937,9 @@ class ServerCLITests(testing.TestCase):
         self.assertEqual(result.exit_code, 2)
         self.assertIsInstance(result.exception, exceptions.CLIAbort)
 
-    @mock.patch('SoftLayer.CLI.formatting.confirm')
-    def test_upgrade_test(self, confirm_mock):
-        confirm_mock.return_value = True
+    def test_upgrade_test(self):
+        order_mock = self.set_mock('SoftLayer_Product_Order', 'verifyOrder')
+        order_mock.return_value = SoftLayer_Product_Order.hardware_verifyOrder
         result = self.run_command(['hw', 'upgrade', '100', '--test', '--memory=32', '--public-bandwidth=500',
                                    '--drive-controller=RAID', '--network=10000 Redundant'])
         self.assert_no_fail(result)
@@ -946,6 +947,8 @@ class ServerCLITests(testing.TestCase):
     @mock.patch('SoftLayer.CLI.formatting.confirm')
     def test_upgrade_add_disk(self, confirm_mock):
         confirm_mock.return_value = True
+        order_mock = self.set_mock('SoftLayer_Product_Order', 'placeOrder')
+        order_mock.return_value = SoftLayer_Product_Order.hardware_placeOrder
         result = self.run_command(['hw', 'upgrade', '100', '--add-disk=1000', '2'])
 
         self.assert_no_fail(result)
@@ -953,6 +956,8 @@ class ServerCLITests(testing.TestCase):
     @mock.patch('SoftLayer.CLI.formatting.confirm')
     def test_upgrade_resize_disk(self, confirm_mock):
         confirm_mock.return_value = True
+        order_mock = self.set_mock('SoftLayer_Product_Order', 'placeOrder')
+        order_mock.return_value = SoftLayer_Product_Order.hardware_placeOrder
         result = self.run_command(['hw', 'upgrade', '100', '--resize-disk=1000', '1'])
 
         self.assert_no_fail(result)
@@ -981,7 +986,13 @@ class ServerCLITests(testing.TestCase):
     @mock.patch('SoftLayer.CLI.formatting.confirm')
     def test_upgrade(self, confirm_mock):
         confirm_mock.return_value = True
+        order_mock = self.set_mock('SoftLayer_Product_Order', 'placeOrder')
+        order_mock.return_value = SoftLayer_Product_Order.hardware_placeOrder
         result = self.run_command(['hw', 'upgrade', '100', '--memory=32', '--public-bandwidth=500',
                                    '--drive-controller=RAID', '--network=10000 Redundant'])
 
         self.assert_no_fail(result)
+
+    def test_components(self):
+        result = self.run_command(['hardware', 'detail', '100', '--components'])
+        self.assert_no_fail(result)
