@@ -879,7 +879,7 @@ class HardwareTests(testing.TestCase):
     def test_upgrade(self):
         result = self.hardware.upgrade(1, memory=32)
 
-        self.assertEqual(result, True)
+        self.assertEqual(result['orderId'], 1234)
         self.assert_called_with('SoftLayer_Product_Order', 'placeOrder')
         call = self.calls('SoftLayer_Product_Order', 'placeOrder')[0]
         order_container = call.args[0]
@@ -891,7 +891,7 @@ class HardwareTests(testing.TestCase):
         disk_list.append(disks)
         result = self.hardware.upgrade(1, disk=disk_list)
 
-        self.assertEqual(result, True)
+        self.assertEqual(result['orderId'], 1234)
         self.assert_called_with('SoftLayer_Product_Order', 'placeOrder')
         call = self.calls('SoftLayer_Product_Order', 'placeOrder')[0]
         order_container = call.args[0]
@@ -903,7 +903,7 @@ class HardwareTests(testing.TestCase):
         disk_list.append(disks)
         result = self.hardware.upgrade(1, disk=disk_list)
 
-        self.assertEqual(result, True)
+        self.assertEqual(result['orderId'], 1234)
         self.assert_called_with('SoftLayer_Product_Order', 'placeOrder')
         call = self.calls('SoftLayer_Product_Order', 'placeOrder')[0]
         order_container = call.args[0]
@@ -912,14 +912,14 @@ class HardwareTests(testing.TestCase):
     def test_upgrade_blank(self):
         result = self.hardware.upgrade(1)
 
-        self.assertEqual(result, False)
+        self.assertEqual(result, None)
         self.assertEqual(self.calls('SoftLayer_Product_Order', 'placeOrder'), [])
 
     def test_upgrade_full(self):
         result = self.hardware.upgrade(1, memory=32, nic_speed="10000 Redundant", drive_controller="RAID",
                                        public_bandwidth=500, test=False)
 
-        self.assertEqual(result, True)
+        self.assertEqual(result['orderId'], 1234)
         self.assert_called_with('SoftLayer_Product_Order', 'placeOrder')
         call = self.calls('SoftLayer_Product_Order', 'placeOrder')[0]
         order_container = call.args[0]
@@ -928,6 +928,26 @@ class HardwareTests(testing.TestCase):
         self.assertIn({'id': 22482}, order_container['prices'])
         self.assertIn({'id': 50357}, order_container['prices'])
 
+    def test_get_components(self):
+        result = self.hardware.get_components(1234)
+        components = [{'hardwareComponentModelId': 147,
+                       'hardwareId': 1234,
+                       'id': 369,
+                       'modifyDate': '2017-11-10T16:59:38-06:00',
+                       'serviceProviderId': 1,
+                       'hardwareComponentModel':
+                           {'name': 'IMM2 - Onboard',
+                            'firmwares':
+                                [{'createDate': '2020-09-24T13:46:29-06:00',
+                                  'version': '5.60'},
+                                 {'createDate': '2019-10-14T16:51:12-06:00',
+                                  'version': '5.10'}]}}]
+        self.assert_called_with('SoftLayer_Hardware_Server', 'getComponents')
+        self.assertEqual(result, components)
+        self.assertEqual(result[0]['hardwareId'], 1234)
+        self.assertEqual(result[0]['hardwareComponentModel']['name'], 'IMM2 - Onboard')
+        self.assertEqual(result[0]['hardwareComponentModel']['firmwares'][0]['version'], '5.60')
+
 
 class HardwareHelperTests(testing.TestCase):
 
